@@ -8,7 +8,7 @@
 
 	// Language and character set
 	$lang['applang'] = '&#268;esky';
-	$lang['appcharset'] = 'utf8';
+	$lang['appcharset'] = 'utf-8';
 	$lang['applocale'] = 'cs_CZ';
 	$lang['appdbencoding'] = 'UNICODE';
 	$lang['applangdir'] = 'ltr';
@@ -85,7 +85,7 @@
 	$lang['strimport'] = 'Import';
 	$lang['stradmin'] = 'Admin';
 	$lang['strvacuum'] = 'Vacuum';
-	$lang['stranalyze'] = 'Analyzovt&#357;';
+	$lang['stranalyze'] = 'Analyzovat';
 	$lang['strclusterindex'] = 'Cluster';
 	$lang['strreindex'] = 'Reindex';
 	$lang['strrun'] = 'Spustit';
@@ -302,7 +302,6 @@
 	$lang['strcachevalue'] = 'Cache hodnota';
 	$lang['strlogcount'] = 'Log Count';
 	$lang['striscycled'] = 'Je cyklick&#225;?';
-	$lang['striscalled'] = 'Je called?';
 	$lang['strsequenceneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev sekvence.';
 	$lang['strsequencereset'] = 'Reset sekvence.';
 	$lang['strsequenceresetbad'] = 'Reset sekvence se nepovedl.';
