@@ -6,7 +6,7 @@
 	 * how many SQL statements have been strung together with semi-colons
 	 * @param $query The SQL query string to execute
 	 *
-	 * $Id: sql.php,v 1.32.4.1 2007/05/28 17:21:56 ioguix Exp $
+	 * $Id: sql.php,v 1.43 2008/01/10 20:19:27 xzilla Exp $
 	 */
 
 	// Prevent timeouts on large exports (non-safe mode only)
@@ -42,7 +42,7 @@
 						$id = (($i % 2) == 0 ? '1' : '2');
 						echo "<tr>\n";
 						foreach ($row as $k => $v) {
-							echo "<td class=\"data{$id}\" nowrap=\"nowrap\">", $misc->printVal($v, pg_fieldtype($rs, $k), array('null' => true)), "</td>";
+							echo "<td class=\"data{$id}\" style=\"white-space:nowrap;\">", $misc->printVal($v, pg_fieldtype($rs, $k), array('null' => true)), "</td>";
 						}							
 						echo "</tr>\n";
 						$row = pg_fetch_row($rs);
@@ -69,24 +69,26 @@
 			}
 		}
 	}
+
 	
-	// Determine explain version of SQL
-	if ($data->hasFullExplain() && isset($_POST['explain']) && isset($_POST['query'])) {
-		$_POST['query'] = $data->getExplainSQL($_POST['query'], false);
-		$_REQUEST['query'] = $_POST['query'];
+	// Pagination maybe set by a get link that has it as FALSE,
+	// if that's the case, unset the variable.
+
+	if (isset($_REQUEST['paginate']) && $_REQUEST['paginate'] == 'f') {
+		unset($_REQUEST['paginate']);
+		unset($_POST['paginate']);
+		unset($_GET['paginate']);
 	}
-	elseif ($data->hasFullExplain() && isset($_POST['explain_analyze']) && isset($_POST['query'])) {
-		$_POST['query'] = $data->getExplainSQL($_POST['query'], true);
-		$_REQUEST['query'] = $_POST['query'];
-	}
-	
 	// Check to see if pagination has been specified. In that case, send to display
 	// script for pagination
-	if (isset($_POST['paginate']) && !isset($_POST['explain']) && !isset($_POST['explain_analyze'])) {
+	/* if a file is given or the request is an explain, do not paginate */
+	if (isset($_REQUEST['paginate']) && !(isset($_FILES['script']) && $_FILES['script']['size'] > 0)
+			&& (preg_match('/^\s*explain/i', $_REQUEST['query']) == 0)) {
 		include('./display.php');
 		exit;
 	}
 	
+	$subject = isset($_REQUEST['subject'])? $_REQUEST['subject'] : '';
 	$misc->printHeader($lang['strqueryresults']);
 	$misc->printBody();
 	$misc->printTrail('database');
@@ -112,27 +114,31 @@
 	else {
 		// Set fetch mode to NUM so that duplicate field names are properly returned
 		$data->conn->setFetchMode(ADODB_FETCH_NUM);
-		$rs = $data->conn->Execute($_POST['query']);
+		$rs = $data->conn->Execute($_REQUEST['query']);
 
 		// $rs will only be an object if there is no error
 		if (is_object($rs)) {
+			// Request was run, saving it in history
+			if(!isset($_REQUEST['nohistory']))
+				$misc->saveScriptHistory($_REQUEST['query']);
+
 			// Now, depending on what happened do various things
 	
 			// First, if rows returned, then display the results
 			if ($rs->recordCount() > 0) {
 				echo "<table>\n<tr>";
-				foreach ($rs->f as $k => $v) {
+				foreach ($rs->fields as $k => $v) {
 					$finfo = $rs->fetchField($k);
 					echo "<th class=\"data\">", $misc->printVal($finfo->name), "</th>";
 				}
-	
+                                echo "</tr>\n";	
 				$i = 0;		
 				while (!$rs->EOF) {
 					$id = (($i % 2) == 0 ? '1' : '2');
 					echo "<tr>\n";
-					foreach ($rs->f as $k => $v) {
+					foreach ($rs->fields as $k => $v) {
 						$finfo = $rs->fetchField($k);
-						echo "<td class=\"data{$id}\" nowrap=\"nowrap\">", $misc->printVal($v, $finfo->type, array('null' => true)), "</td>";
+						echo "<td class=\"data{$id}\" style=\"white-space:nowrap;\">", $misc->printVal($v, $finfo->type, array('null' => true)), "</td>";
 					}							
 					echo "</tr>\n";
 					$rs->moveNext();
@@ -145,7 +151,8 @@
 			elseif ($data->conn->Affected_Rows() > 0) {
 				echo "<p>", $data->conn->Affected_Rows(), " {$lang['strrowsaff']}</p>\n";
 			}
-			// Otherwise output nothing...
+			// Otherwise nodata to print
+			else echo '<p>', $lang['strnodata'], "</p>\n";
 		}
 	}
 
@@ -167,14 +174,35 @@
 	}
 	
 	echo "<p>{$lang['strsqlexecuted']}</p>\n";
+			
+	echo "<ul class=\"navlink\">\n";
+	
+	// Return
+	if (isset($_REQUEST['return_url']) && isset($_REQUEST['return_desc']))
+		echo "\t<li><a href=\"{$_REQUEST['return_url']}\">{$_REQUEST['return_desc']}</a></li>\n";
 
-	echo "<p><a class=\"navlink\" href=\"database.php?database=", urlencode($_REQUEST['database']),
-		"&amp;server=", urlencode($_REQUEST['server']), "&amp;action=sql&amp;query=", urlencode($_POST['query']), "\">{$lang['streditsql']}</a>";
-	if ($conf['show_reports'] && isset($rs) && is_object($rs) && $rs->recordCount() > 0) {
-		echo " | <a class=\"navlink\" href=\"reports.php?{$misc->href}&amp;action=create&amp;report_sql=",
-			urlencode($_POST['query']), "\">{$lang['strcreatereport']}</a>";
+	// Edit		
+	echo "\t<li><a href=\"database.php?database=", urlencode($_REQUEST['database']),
+		"&amp;server=", urlencode($_REQUEST['server']), "&amp;action=sql&amp;query=", urlencode($_REQUEST['query']), "\">{$lang['streditsql']}</a></li>\n";
+				
+	// Create report
+	if (($subject !== 'report') && $conf['show_reports'] && isset($rs) && is_object($rs) && $rs->recordCount() > 0)
+		echo "\t<li><a href=\"reports.php?{$misc->href}&amp;action=create&amp;report_sql=",
+			urlencode($_REQUEST['query']), "\">{$lang['strcreatereport']}</a></li>\n";
+	
+	// Create view and download
+	if (isset($_REQUEST['query']) && isset($rs) && is_object($rs) && $rs->recordCount() > 0) {
+		// Report views don't set a schema, so we need to disable create view in that case
+		if (isset($_REQUEST['schema'])) 
+			echo "\t<li><a href=\"views.php?action=create&amp;formDefinition=",
+				urlencode($_REQUEST['query']), "&amp;{$misc->href}\">{$lang['strcreateview']}</a></li>\n";
+		echo "\t<li><a href=\"dataexport.php?query=", urlencode($_REQUEST['query']);
+		if (isset($_REQUEST['search_path']))
+			echo "&amp;search_path=", urlencode($_REQUEST['search_path']);
+		echo "&amp;{$misc->href}\">{$lang['strdownload']}</a></li>\n";
 	}
-	echo "</p>\n";
+
+	echo "</ul>\n";
 	
 	$misc->printFooter();
 ?>
